@@ -26,7 +26,6 @@ var (
 	reBracket      = regexp.MustCompile(`^(\.\w*)+\[]`)
 	reBracketStart = regexp.MustCompile(`^\.\[`)
 	reDotStart     = regexp.MustCompile(`^\.`)
-	reMap          = regexp.MustCompile(`^map\(.+?\)$`)
 	reAt           = regexp.MustCompile(`^@`)
 )
 
@@ -47,14 +46,6 @@ func transpile(code string) string {
 		return "x" + code
 	}
 
-	if reMap.MatchString(code) {
-		s := code[4 : len(code)-1]
-		if s[0] == '.' {
-			s = "x" + s
-		}
-		return fmt.Sprintf(`x.map((x, i) => apply(%s, x, i))`, s)
-	}
-
 	if reAt.MatchString(code) {
 		jsCode := transpile(code[1:])
 		return fmt.Sprintf(`x.map((x, i) => apply(%s, x, i))`, jsCode)
